var structjs_stream_info =
[
    [ "Config", "structjs_stream_info.html#adcc402d28e0ee443419e9b549da233c6", null ],
    [ "Created", "structjs_stream_info.html#a578ce52a275c690dd4627c1d119c7838", null ],
    [ "State", "structjs_stream_info.html#a766ac56dec3bd19fa5b9861fb5f64397", null ],
    [ "Cluster", "structjs_stream_info.html#a8d10d6fdc3f713ac726c72cae06a209a", null ],
    [ "Mirror", "structjs_stream_info.html#ab71aae7e4f6c62e2a09a3a52c9e4fa2a", null ],
    [ "Sources", "structjs_stream_info.html#a2e7ca48a93fe57265609e7e0cd3fa386", null ],
    [ "SourcesLen", "structjs_stream_info.html#af14110cb1f8e16e3dade8d9f7c2fd672", null ],
    [ "Alternates", "structjs_stream_info.html#a720c4ff9090bafda50000843810ab1bb", null ],
    [ "AlternatesLen", "structjs_stream_info.html#ad37a5fd700bd5df54e5002c7de51c3ad", null ]
];